# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add qa notes to ingested notification

Revision ID: af714f622fcb
Revises: edf4886e1d9c
Create Date: 2021-12-07 13:24:35.872503

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "af714f622fcb"
down_revision = "edf4886e1d9c"
branch_labels = None
depends_on = None


template = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{request_id}} has been ingested


Dear User,

Thank you for using NRAO Workspaces.

Your {{capability_name}} request #{{request_id}} has successfully had its products ingested into the archive.

{{#qa}}
QA NOTES for request #{{request_id}}:
{{qa}}
{{/qa}}

Best regards,
NRAO Workspaces
"""

old_template = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{request_id}} has been ingested


Dear User,

Thank you for using NRAO Workspaces.

Your {{capability_name}} request #{{request_id}} has successfully had its products ingested into the archive.

Best regards,
NRAO Workspaces
"""


def upgrade():
    op.execute(
        f"""
        UPDATE notification_templates
        SET template = '{template}'
        WHERE name = 'ingested_email'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE notification_templates
        SET template = '{old_template}'
        WHERE name = 'ingested_email'
        """
    )
